**********************************************************
*AnalyzeIncumbentGame-VaryingInstructions.do

*Analyze the results of the incumbent game fielded on Mechanical
*Turk by Huber, Hill, and Lenz in March and April 2011.
*Uses data created by LoadIncumbentGame.do.
*Version 2 creates an alternative regression table.
**********************************************************

clear
set more off
capture log using "AnalyzeIncumbentGame-VaryingInstructionsV2.txt", text replace

*Check if model argument has been passed to do file. If
*not, default to reg.
if ("`1'" == "") {
  local model "reg"
}
else {
  local model "`1'"
}

use incumbentGameData.dta, clear
*Drop folks who were assigned to instructions round 1; an error in the web design
*led them to not view the instructions at any point.
count
drop if instructionsround == 1
count

*A second version of this game, with instructions only in rounds
*1 and 12 was run in May.  Append here for that analysis.
* Note version 10 prefix here. Append works differently with Stata 12 for string to text conversions and was crashing here. In Stata 12, you would need to add the ,force option after the append if you didn't for the version 10 command processor
version 10: append using "../scripts-experiments2and3/incumbentGameData-VaryingInstructions.dta"
count
gen fromsecondgame = (gametypeid == 6)
label var fromsecondgame "Played second iteration of game"

*Create intervention variable. THIS IS REQUIRED BY RecodeIncumbentGameData.do.
gen intervention = ""
replace intervention = " Instructions  before round 1" if instructionsround == 1
replace intervention = "Informed later (after round  8)"  if instructionsround == 8
replace intervention = "Informed later (after round 12)" if instructionsround == 12
tab intervention

*Generic recoding of variables.
do ../RecodeIncumbentGameData.do

*Create tercile-binned deviations.
qui egen devcuts = cut(devpayments13_16), group(3) icodes
qui replace devcuts = devcuts - 1
label variable devcuts "Terciles of round 13-16 deviations from average (-1, 0, 1)"
qui egen devcuts9_12 = cut(devpayments9_12), group(3) icodes
qui replace devcuts9_12 = devcuts9_12 - 1
label variable devcuts9_12 "Terciles of round  9-12 deviations from average (-1, 0, 1)"

*Create devpayments and devcuts interactions.
foreach var of varlist interv_* {
  local lab : variable label `var'
  local i = subinstr("`var'","interv_","",.)
  qui gen Xdev13_16_`i' = devpayments13_16*`var'
  label variable Xdev13_16_`i' "Average payment deviations in Rounds 13-16*`lab'"
  qui gen Xdev9_12_`i' = devpayments9_12*`var'
  label variable Xdev9_12_`i' "Average payment deviations in Rounds 9-12*`lab'"
  qui gen Xdevcuts_`i' = devcuts*interv_`i'
  label variable Xdevcuts_`i' "Terciles of round 13-16 deviations*`lab'"
  qui gen Xdevcuts9_12_`i' = devcuts9_12*interv_`i'
  label variable Xdevcuts9_12_`i' "Terciles of round  9-12 deviations*`lab'"
  
}

*Drop an intervention indicator as excluded category, manually.
foreach var of varlist interv_* {
  local vlab : variable label `var'
  if ("`vlab'" == "Instructions  before round 1") {
    di "'`vlab'' is excluded intervention category."
    drop `var'
  }
}


****************************
*Simple description of data.
****************************

*Binary indicator for whether payments in round 1-16 over 1200
gen avgover1200=(payments1_16>12)

*Is there a difference in probability of retaining given average over 1200

*yes in entire sample
prtest keepallocator, by(avgover1200)
*yes, even more so for instructions in round 1
prtest keepallocator if instructionsround==1, by(avgover1200)

*Create indicator for correct decision
gen correct=(avgover1200==keepallocator)

*Deviation in payouts from cutpoint of 1200
gen distancefrom1200=abs(payments1_16-12)
label var distancefrom1200 "Abs. value difference between avg. payouts and 1200 (in 100s)"
*So error rate is increasing in distance from 1200
twoway (lowess correct distancefrom1200), scheme(s1mono) ytitle(Proportion Correct Decisions)
regress correct distancefrom1200

  **************************************************
  *Paper Table 1.
  **************************************************
  levelsof intervention, local(ivalues)
  *Toggle here to include payavggt1200inrounds5_8
  egen payments5_8   = rowmean(pay5-pay8)
  gen  payavggt1200inrounds5_8 = (payments5_8 > 1200)
  foreach var of varlist payavggt1200inrounds5_8 {
    local rounds = substr("`var'",strpos("`var'","rounds")+6,5)
    local roundstring = subinstr("`rounds'","_","-",.)
    label variable `var' "Average > 1200 in Rounds `roundstring'"
    local ctr 1
    foreach i of local ivalues {
      gen Xpayavg`rounds'_`ctr' = `var'*(intervention == "`i'")
      label variable Xpayavg`rounds'_`ctr' "Average > 1200 in Rounds `roundstring' * `i'"
      local ctr = `ctr' + 1
    }
  }

  local repl "replace"
  foreach mod in "reg" "probit" {
    local mtext "OLS"
    if ("`mod'" == "probit") local mtext "Probit"
    *Cutpoint payments.
    `mod' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds13_16 Xpayavg1_16_3  Xpayavg13_16_3 interv_3 if interv_2 == 0
    outreg using "../papertables/Table01_EventSalienceV2.out", se ctitle("Allocator Retention, Cutpoint payments, `mtext'") bracket rdec(3) 3aster `repl'
    `mod' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds9_12 payavggt1200inrounds13_16 Xpayavg1_16_2 Xpayavg9_12_2  Xpayavg13_16_2 interv_2 if interv_3 == 0
    outreg using "../papertables/TableA01_EventSalienceV2-9-12.out", se ctitle("Allocator Retention, Cutpoint payments, `mtext'") bracket rdec(3) 3aster `repl'
    local repl "append"

    *Continuous payments.
    `mod' keepallocator payments1_16 devpayments13_16 Xpayments1_16_3 Xdev13_16_3 interv_3 if interv_2 == 0
    outreg using "../papertables/Table01_EventSalienceV2.out", se ctitle("Allocator Retention, Continuous payments, `mtext'") bracket rdec(3) 3aster `repl'
    `mod' keepallocator payments1_16 devpayments9_12 devpayments13_16 Xpayments1_16_2 Xdev9_12_2 Xdev13_16_2 interv_2 if interv_3 == 0
    outreg using "../papertables/TableA01_EventSalienceV2-9-12.out", se ctitle("Allocator Retention, Continuous payments, `mtext'") bracket rdec(3) 3aster `repl'
    
    *Binned payments.
    `mod' keepallocator payments1_16 devcuts Xpayments1_16_3 Xdevcuts_3 interv_3 if interv_2 == 0
    outreg using "../papertables/Table01_EventSalienceV2.out", se ctitle("Allocator Retention, Binned payments, `mtext'") bracket rdec(3) 3aster `repl'
    `mod' keepallocator payments1_16 devcuts9_12 devcuts Xpayments1_16_2 Xdevcuts9_12_2 Xdevcuts_2 interv_2 if interv_3 == 0
    outreg using "../papertables/TableA01_EventSalienceV2-9-12.out", se ctitle("Allocator Retention, Binned payments, `mtext'") bracket rdec(3) 3aster `repl'
  }
  
  *Test coefficients across interventions.
  `model' keepallocator Xpayavg1_16_* Xpayavg1_4_* Xpayavg5_8_* Xpayavg9_12_* Xpayavg13_16_* interv_*
  *Test all-round cutpoint by intervention.
  test Xpayavg1_16_1 = Xpayavg1_16_2
  test Xpayavg1_16_1 = Xpayavg1_16_3
  test Xpayavg1_16_2 = Xpayavg1_16_3
  *Test that the round 9-12 cutpoint is largest in intervention 2 (instructions round 8).
  test Xpayavg9_12_2 = Xpayavg9_12_1
  test Xpayavg9_12_2 = Xpayavg9_12_3  
  *Overall test that respondents instructed later overweight final rounds (in specifications below).
  *To be written out to file sigtable.
  local modeltext "OLS"
  if ("`model'" == "probit") local modeltext "Probit"
  *Check to see that file connection sigtable is open.
  local fileconnection 0
  file query
  if (`r(N)' > 0) local fileconnection 1
  *Cutpoint tests.
  local hypothesis "Overweighted recent incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on rounds 13-16 greater with instructions in round 12 rather than round 1"
  `model' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds13_16 Xpayavg1_16_3 Xpayavg13_16_3 interv_3 if interv_2 == 0
  local b = _b[Xpayavg13_16_3]
  test Xpayavg13_16_3
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Cutpoint,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local hypothesis "Underweighted overall incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on overall average greater with instructions in round 1 rather than round 12"
  local b = _b[Xpayavg1_16_3]
  test Xpayavg1_16_3
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Cutpoint,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  *Continuous tests.
  local hypothesis "Overweighted recent incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on round 13-16 deviations greater with instructions in round 12 rather than round 1"
  `model' keepallocator payments1_16 devpayments13_16 Xpayments1_16_3 Xdev13_16_3 interv_3 if interv_2 == 0
  local b = _b[Xdev13_16_3]
  test Xdev13_16_3
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local hypothesis "Underweighted overall incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on overall average greater with instructions in round 1 rather than round 12"
  local b = _b[Xpayments1_16_3]
  test Xpayments1_16_3
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  *Binned deviation tests.
  local hypothesis "Overweighted recent incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on binned round 13-16 deviations greater with instructions in round 12 rather than round 1"
  `model' keepallocator payments1_16 devcuts Xpayments1_16_3 Xdevcuts_3 interv_3 if interv_2 == 0
  local b = _b[Xdevcuts_3]
  test Xdevcuts_3
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Binned,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local hypothesis "Underweighted overall incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on overall average greater with instructions in round 1 rather than round 12"
  local b = _b[Xpayments1_16_3]
  test Xpayments1_16_3
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Binned,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n

  capture drop *5_8*
  
/************************
Begin Graphs
************************/
   
gen dumb = .
replace dumb = 6 in 1
replace dumb = 8 in 2
replace dumb = 10 in 3
replace dumb = 12 in 4
replace dumb = 14 in 5
replace dumb = 16 in 6
replace dumb = 18 in 7
label values dumb payments
*Deviations in rounds 13-16 for instructions round 1 and 12.
preserve
drop if intervention == "Informed later (after round  8)"
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if devcuts==1, lpattern(solid)) (lpoly keepallocator payments1_16 if devcuts==0, lpattern(dot)) (lpoly keepallocator payments1_16 if devcuts==-1, lpattern(dash)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Lucky last four rounds (Top tercile deviations)" 3 "Middling last four rounds (Middle tercile deviations)"  4 "Unlucky last four rounds (Bottom tercile deviations)") cols(1) size(small) region(fcolor(none)) title(Average Deviation in Payments in Rounds 13 to 16 From Average in Rounds 1 to 16, size(vsmall))) scheme(s2mono) name(rd1316pymteffects, replace) xsize(7.5) ysize(10) by(, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))) by(intervention, cols(1) iscale(*.75)) subtitle(, fcolor(white) lcolor(black))
graph export "../graphs/Figure04_RetentionByInstructionsAndDevs-1316v2.eps", as(eps) preview(off) replace
*N in each line.
tab intervention devcuts if payments1_16 != .
restore

*Deviations in rounds 9-12 for instructions round 1 and 8.
preserve
drop if intervention == "Informed later (after round 12)"
drop devcuts
qui egen devcuts = cut(devpayments9_12), group(3) icodes
qui replace devcuts = devcuts - 1
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if devcuts==1, lpattern(solid)) (lpoly keepallocator payments1_16 if devcuts==0, lpattern(dot)) (lpoly keepallocator payments1_16 if devcuts==-1, lpattern(dash)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Lucky last four rounds (Top tercile deviations)" 3 "Middling last four rounds (Middle tercile deviations)"  4 "Unlucky last four rounds (Bottom tercile deviations)") cols(1) size(small) region(fcolor(none)) title(Average Deviation in Payments in Rounds 9 to 12 From Average in Rounds 1 to 16, size(vsmall))) scheme(s2mono) name(rd1316pymteffects, replace) xsize(7.5) ysize(10) by(, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))) by(intervention, cols(1) iscale(*.75)) subtitle(, fcolor(white) lcolor(black))
graph export "../graphs/Figure04_RetentionByInstructionsAndDevs-0912v2.eps", as(eps) preview(off) replace
*N in each line.
tab intervention devcuts if payments1_16 != .
restore

/************************
End Graphs
************************/

****************************
*Check on randomization.
****************************
foreach var of varlist interv_* {
  qui `model' `var' pay1-pay16
  testparm pay*
}

capture log close
