**********************************************************
*AnalyzeIncumbentGame-VaryingLottery.do

*Analyze the results of the incumbent game fielded on Mechanical
*Turk by Huber, Hill, and Lenz in April and May 2011.
*Uses data created by LoadIncumbentGame.do.
**********************************************************

clear
set more off
capture log using "AnalyzeIncumbentGame-VaryingLotteryV2.txt", txt replace

*Check if model argument has been passed to do file. If
*not, default to reg.
if ("`1'" == "") {
  local model "reg"
}
else {
  local model "`1'"
}

use incumbentGameData-VaryingLottery.dta, clear


*Create intervention variable. THIS IS REQUIRED BY RecodeIncumbentGameData.do.
gen intervention = ""
replace intervention = "Lottery Payment -5000, Round  8" if lotterypay == -5000 & lotteryround == 8
replace intervention = "Lottery Payment -5000, Round 16" if lotterypay == -5000 & lotteryround == 16
replace intervention = "Lottery Payment 0, Round  8" if lotterypay == 0 & lotteryround == 8
replace intervention = "Lottery Payment 0, Round 16" if lotterypay == 0 & lotteryround == 16
replace intervention = "Lottery Payment 5000, Round  8" if lotterypay == 5000 & lotteryround == 8
replace intervention = "Lottery Payment 5000, Round 16" if lotterypay == 5000 & lotteryround == 16
tab intervention, miss

*Specific to lottery analysis: lottery payment indicators irrespective of lottery round.
gen lotteryhi = (lotterypay ==  5000)
gen lotterylo = (lotterypay == -5000)
label variable lotteryhi "Lottery Payment  5000, Either Round"
label variable lotterylo "Lottery Payment -5000, Either Round"
tab lotteryhi lotterylo

*Generic recoding of variables.
do ../RecodeIncumbentGameData.do

*Drop an intervention indicator as excluded category, manually.
foreach var of varlist interv_* {
  local vlab : variable label `var'
  if ("`vlab'" == "Lottery Payment 0, Round  8") {
    di "'`vlab'' is excluded intervention category."
    drop `var'
  }
}

****************************
*Simple description of data.
****************************

*Binary indicator for whether payments in round 1-16 over 1200
gen avgover1200=(payments1_16>12)

*Is there a difference in probability of retaining given average over 1200

*yes in entire sample
prtest keepallocator, by(avgover1200)

*Create indicator for correct decision
gen correct=(avgover1200==keepallocator)

*Deviation in payouts from cutpoint of 1200
gen distancefrom1200=abs(payments1_16-12)
label var distancefrom1200 "Abs. value difference between avg. payouts and 1200 (in 100s)"
*So error rate is increasing in distance from 1200
twoway (lowess correct distancefrom1200), scheme(s1mono) ytitle(Proportion Correct Decisions)
regress correct distancefrom1200

*Plot of retention rate by continuous payment average and lottery.
gen dumb = .
replace dumb = 6 in 1
replace dumb = 8 in 2
replace dumb = 10 in 3
replace dumb = 12 in 4
replace dumb = 14 in 5
replace dumb = 16 in 6
replace dumb = 18 in 7
label values dumb payments
*Version without line for no lottery.
*twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if lotterypay==50, lpattern(solid)) (lpoly keepallocator payments1_16 if lotterypay==-50, lpattern(dash)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Win 5000 Tokens" 3 "Lose 5000 Tokens") title("Lottery Outcome", size(medium)))  scheme(s2mono) name(LotteryAvgPaymentEffects, replace) xsize(7.5) ysize(5) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
*Version with line for no lottery.
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if lotterypay==50, lpattern(solid)) (lpoly keepallocator payments1_16 if lotterypay==0, lpattern(dot)) (lpoly keepallocator payments1_16 if lotterypay==-50, lpattern(dash)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Win 5000 Tokens" 3 "Win 0 Tokens" 4 "Lose 5000 Tokens") title("Lottery Outcome", size(medium)))  scheme(s2mono) name(LotteryAvgPaymentEffects, replace) xsize(7.5) ysize(5) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "../graphs/Figure06_ReelectionByLotteryAndAveragePay.eps", as(eps) preview(off) replace
tab lotterypay if payments1_16 != .

twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lowess keepallocator  payments1_16 if lotterypay==0) (lowess keepallocator  payments1_16 if lotterypay==50) (lowess keepallocator payments1_16 if lotterypay==-50), scheme(s2mono) legend(order(2 "Lottery 0" 3 "Lottery +" 4 "Lottery -"))

****************************
*Paper Appendix Table 2.
****************************

  local repl "replace"
  foreach mod in "reg" "probit" {
    local mtext "OLS"
    if ("`mod'" == "probit") local mtext "Probit"
    *Cutpoint payments.
    `mod' keepallocator lotteryhi lotterylo payavggt1200inrounds1_16 
    outreg using "../papertables/TableA02_IrrelevantInfoV2.out", se ctitle("Allocator Retention, All Participants, `mtext'") bracket rdec(3) 3aster `repl'
    local repl "append"
    
    *Continuous payments.
    `mod' keepallocator lotteryhi lotterylo payments1_16 
    outreg using "../papertables/TableA02_IrrelevantInfoV2.out", se ctitle("Allocator Retention, All Participants, `mtext'") bracket rdec(3) 3aster `repl'
  }
  
  *Overall test that respondents instructed later overweight final rounds (in specifications below).
  *To be written out to file sigtable.
  `model' keepallocator lotteryhi lotterylo payments1_16 
  local hypothesis "Allowed an unrelated lottery that affected their welfare to influence their choices"
  local modeltext "OLS"
  if ("`model'" == "probit") local modeltext "Probit"
  *Check to see that file connection sigtable is open.
  local fileconnection 0
  file query
  if (`r(N)' > 0) local fileconnection 1
  local testtext "Coefficient on lottery win and lottery loss coefficients are zero"
  lincom lotteryhi - lotterylo
  local b = `r(estimate)'
  test lotteryhi - lotterylo = 0
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`r(p)'"
  if (`fileconnection') file write sigtable "`outrow'" _n

*All interventions.
`model' keepallocator interv_* 
*round 8 differences
lincom (interv_5 - interv_1)
*round 16 differences
lincom (interv_6 - interv_2)
*differences in diferences rd 16 - 8
lincom (interv_6 - interv_2) - (interv_5 - interv_1)
  
*Only direct effects.
`model' keepallocator payavggt1200inrounds1_16 interv_* 
*round 8 differences
lincom (interv_5 - interv_1)
*round 16 differences
lincom (interv_6 - interv_2)
*differences in diferences rd 16 - 8
lincom (interv_6 - interv_2) - (interv_5 - interv_1)

****************************
*Treatment effect heterogeneity by timetoretention and education.
****************************
*Mean deviate time to retention.
qui summ timetoretention
gen timetoretain_md = timetoretention - `r(mean)'
label variable timetoretain_md "Time from start to retention in minutes (mean-deviated)"
gen lotteryhiXtimetoretain = lotteryhi*timetoretain_md
label variable lotteryhiXtimetoretain "Lottery 5000*Time to retention"
gen lotteryloXtimetoretain = lotterylo*timetoretain_md
label variable lotteryloXtimetoretain "Lottery -5000*Time to retention"
gen payments1_16Xtimetoretain = payments1_16*timetoretain_md
label variable payments1_16Xtimetoretain "Average Payments Rounds 1-16*Time to retention"

`model' keepallocator payments1_16 lotteryhi lotterylo
outreg using "../papertables/TableA04_Lottery-ByAttentiveness.out", se bracket ctitle("Allocator Retention") rdec(3) 3aster replace
`model' keepallocator payments1_16 lotteryhi lotterylo lotteryhiXtime lotteryloXtime timetoretain_md payments1_16Xtimetoretain
outreg using "../papertables/TableA04_Lottery-ByAttentiveness.out", se bracket ctitle("Allocator Retention") rdec(3) 3aster append

*Truncate sample at 10th and 90th percentiles.
qui centile timetoretain_md, centile(10 90)
local c1 `r(c_1)'
local c2 `r(c_2)'
qui replace timetoretain_md = `c1' if timetoretain_md <= `c1' 
qui replace timetoretain_md = `c2' if timetoretain_md >= `c2'
qui replace lotteryhiXtimetoretain = lotteryhi*timetoretain_md
qui replace lotteryloXtimetoretain = lotterylo*timetoretain_md
qui replace payments1_16Xtimetoretain = payments1_16*timetoretain_md
`model' keepallocator payments1_16 lotteryhi lotterylo lotteryhiXtime lotteryloXtime timetoretain_md payments1_16Xtimetoretain
outreg using "../papertables/TableA04_Lottery-ByAttentiveness.out", se bracket rdec(3) 3aster ctitle("Allocator Retention, Time to Retain Truncated") append
*By terciles.
qui centile timetoretain_md, centile(33 66)
`model' keepallocator payments1_16 lotteryhi lotterylo if timetoretain_md < `r(c_1)'
outreg using "../papertables/TableA04_Lottery-ByAttentiveness.out", se bracket rdec(3) 3aster ctitle("Allocator Retention, Time to Retain in lower third") append
qui centile timetoretain_md, centile(33 66)
`model' keepallocator payments1_16 lotteryhi lotterylo if timetoretain_md >= `r(c_1)' &  timetoretain_md <= `r(c_2)'
outreg using "../papertables/TableA04_Lottery-ByAttentiveness.out", se bracket rdec(3) 3aster ctitle("Allocator Retention, Time to Retain in middle third") append
qui centile timetoretain_md, centile(33 66)
`model' keepallocator payments1_16 lotteryhi lotterylo if timetoretain_md > `r(c_2)'
outreg using "../papertables/TableA04_Lottery-ByAttentiveness.out", se bracket rdec(3) 3aster ctitle("Allocator Retention, Time to Retain in upper third") append

drop lotteryhiXtime lotteryloXtime timetoretain_md payments1_16Xtimetoretain

*By education.
gen baplus = (responsepostEducation == "FourYear" | responsepostEducation == "PostGrad")
label variable baplus "Education: Four year college degree or more"
`model' keepallocator payments1_16 lotteryhi lotterylo if baplus == 0
`model' keepallocator payments1_16 lotteryhi lotterylo if baplus == 1

****************************
*Save out current data set for R graphic production.
****************************
count
save "forR-VaryingLottery.dta", replace

****************************
*Check on randomization.
****************************
foreach var of varlist interv_* {
  `model' `var' pay1-pay16
  testparm pay*
}

capture log close
