**********************************************************
*AnalyzeIncumbentGame-VaryingPrime.do

*Analyze the results of the incumbent game fielded on Mechanical
*Turk by Huber, Hill, and Lenz in May 2011.
*Uses data created by LoadIncumbentGame.do.
**********************************************************

clear
set more off
capture log using "AnalyzeIncumbentGame-VaryingPrimeV2.txt", text replace

*Check if model argument has been passed to do file. If
*not, default to reg.
if ("`1'" == "") {
  local model "reg"
}
else {
  local model "`1'"
}

use incumbentGameData-VaryingPrime.dta, clear

*Create intervention variable. THIS IS REQUIRED BY RecodeIncumbentGameData.do.
gen intervention = ""
replace intervention = "Hedonic Prime" if regexm(prime,"how satisfied are you")
replace intervention = "Informational Prime" if regexm(prime,"the average amount given")
replace intervention = "No Prime" if prime == ""
tab intervention, miss

*Generic recoding of variables.
include ../RecodeIncumbentGameData.do

*Create tercile-binned deviations.
qui egen devcuts = cut(devpayments13_16), group(3) icodes
qui replace devcuts = devcuts - 1
label variable devcuts "Terciles of round 13-16 deviations from average (-1, 0, 1)"

*Create devpayments and devcuts interactions.
foreach var of varlist interv_* {
  local lab : variable label `var'
  local i = subinstr("`var'","interv_","",.)
  qui gen Xdev13_16_`i' = devpayments13_16*`var'
  label variable Xdev13_16_`i' "Average payment deviations in Rounds 13-16*`lab'"
  qui gen Xdev9_12_`i' = devpayments9_12*`var'
  label variable Xdev9_12_`i' "Average payment deviations in Rounds 9-12*`lab'"
  qui gen Xdevcuts_`i' = devcuts*interv_`i'
  label variable Xdevcuts_`i' "Terciles of round 13-16 deviations*`lab'" 
}

*Drop an intervention indicator as excluded category, manually.
foreach var of varlist interv_* {
  local vlab : variable label `var'
  if ("`vlab'" == "Informational Prime") {
    di "'`vlab'' is excluded intervention category."
    drop `var'
  }
}

/************************
Begin Graphs
************************/
   
gen dumb = .
replace dumb = 6 in 1
replace dumb = 8 in 2
replace dumb = 10 in 3
replace dumb = 12 in 4
replace dumb = 14 in 5
replace dumb = 16 in 6
replace dumb = 18 in 7
label values dumb payments
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if devcuts==1, lpattern(solid)) (lpoly keepallocator payments1_16 if devcuts==0, lpattern(dot)) (lpoly keepallocator payments1_16 if devcuts==-1, lpattern(dash)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Lucky last four rounds (Top tercile deviations)" 3 "Middling last four rounds (Middle tercile deviations)"  4 "Unlucky last four rounds (Bottom tercile deviations)") cols(1) size(small) region(fcolor(none)) title(Average Deviation in Payments in Rounds 13 to 16 From Average in Rounds 1 to 16, size(vsmall))) scheme(s2mono) name(rd1316pymteffects, replace) xsize(7.5) ysize(10) by(, graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) plotregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))) by(intervention, cols(1) iscale(*.75)) subtitle(, fcolor(white) lcolor(black))
graph export "../graphs/Figure07_RetentionByPrimeAndDevs-1316V2.eps", as(eps) preview(off) replace
*N in each line.
tab intervention devcuts if payments1_16 != .

/************************
End Graphs
************************/

****************************
*Simple description of data.
****************************

*Binary indicator for whether payments in round 1-16 over 1200
gen avgover1200=(payments1_16>12)

*Is there a difference in probability of retaining given average over 1200

*yes in entire sample
prtest keepallocator, by(avgover1200)
*yes, even more so for instructions in round 1
prtest keepallocator if intervention=="No Prime", by(avgover1200)

*Create indicator for correct decision
gen correct=(avgover1200==keepallocator)
table intervention, c(mean correct)

*Deviation in payouts from cutpoint of 1200
gen distancefrom1200=abs(payments1_16-12)
label var distancefrom1200 "Abs. value difference between avg. payouts and 1200 (in 100s)"
*So error rate is increasing in distance from 1200
twoway (lowess correct distancefrom1200), scheme(s1mono) ytitle(Proportion Correct Decisions)
regress correct distancefrom1200

twoway (lowess correct  payments1_16 if intervention=="No Prime")  (lowess correct  payments1_16 if intervention=="Informational Prime")   (lowess correct  payments1_16 if intervention=="Hedonic Prime"), scheme(s2mono)

  **************************************************
  *Paper Table 2.
  **************************************************
  levelsof intervention, local(ivalues)
  *Toggle here to include payavggt1200inrounds5_8
  egen payments5_8   = rowmean(pay5-pay8)
  gen  payavggt1200inrounds5_8 = (payments5_8 > 1200)
  foreach var of varlist payavggt1200inrounds5_8 {
    local rounds = substr("`var'",strpos("`var'","rounds")+6,5)
    local roundstring = subinstr("`rounds'","_","-",.)
    label variable `var' "Average > 1200 in Rounds `roundstring'"
    local ctr 1
    foreach i of local ivalues {
      gen Xpayavg`rounds'_`ctr' = `var'*(intervention == "`i'")
      label variable Xpayavg`rounds'_`ctr' "Average > 1200 in Rounds `roundstring' * `i'"
      local ctr = `ctr' + 1
    }
  }

  local repl "replace"
  foreach mod in "reg" "probit" {
    local mtext "OLS"
    if ("`mod'" == "probit") local mtext "Probit"
    *Cutpoint payments.
    `mod' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds13_16 Xpayavg1_16_1  Xpayavg13_16_1 Xpayavg1_16_3 Xpayavg13_16_3 interv_*
    outreg using "../papertables/Table02_EvaluativePrimingCutpointV2.out", se ctitle("Allocator Retention, Cutpoint payments, `mtext'") bracket rdec(3) addnote("Excluded category is Informational Prime") 3aster `repl'
    local repl "append"

    *Continuous payments.
    `mod' keepallocator payments1_16 devpayments13_16 Xpayments1_16_1 Xdev13_16_1 Xpayments1_16_3 Xdev13_16_3 interv_*
    outreg using "../papertables/Table02_EvaluativePrimingCutpointV2.out", se ctitle("Allocator Retention, Continuous payments, `mtext'") bracket rdec(3) 3aster `repl'
    
    *Binned payments.
    `mod' keepallocator payments1_16 devcuts Xpayments1_16_1 Xdevcuts_1 Xpayments1_16_3 Xdevcuts_3 interv_*
    outreg using "../papertables/Table02_EvaluativePrimingCutpointV2.out", se ctitle("Allocator Retention, Binned payments, `mtext'") bracket rdec(3) 3aster `repl'
  }

  *Test coefficients across interventions.
  `model' keepallocator Xpayavg1_16_* Xpayavg1_4_* Xpayavg5_8_* Xpayavg9_12_* Xpayavg13_16_* interv_*
  *Round 13-16 coefficients equal for hedonic and informational primes.
  test Xpayavg13_16_1 = Xpayavg13_16_2
  *For hedonic and no prime.
  test Xpayavg13_16_1 = Xpayavg13_16_3
  *Test equality of coefficients for each intervention.
  di "Test of hedonic cutpoint coefficient versus informational."
  test Xpayavg1_16_1=Xpayavg1_16_2
  di "Test of hedonic cutpoint coefficient versus no prime."
  test Xpayavg1_16_1=Xpayavg1_16_3
  di "Test of informational cutpoint coefficient versus no prime."
  test Xpayavg1_16_2=Xpayavg1_16_3

  *Overall test that respondents instructed later overweight final rounds (in specifications below).
  *To be written out to file sigtable.
  local modeltext "OLS"
  if ("`model'" == "probit") local modeltext "Probit"
  *Check to see that file connection sigtable is open.
  local fileconnection 0
  file query
  if (`r(N)' > 0) local fileconnection 1
  local hypothesis "Were influenced by rhetoric to give more weight to recent rather than overall incumbent performance"
  *Cutpoint tests.
  local testtext "Coefficient on rounds 13-16 greater with hedonic than informational prime"
  `model' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds13_16 Xpayavg1_16_2 Xpayavg13_16_2 interv_1 if intervention != "No Prime"
  local b = _b[Xpayavg13_16_2]
  test Xpayavg13_16_2
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Cutpoint,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local testtext "Coefficient on overall average greater with informational than hedonic prime"
  local b = _b[Xpayavg1_16_2]
  test Xpayavg1_16_2
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Cutpoint,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  *Continuous tests.
  local testtext "Coefficient on round 13-16 deviations greater with hedonic than informational prime"
  `model' keepallocator payments1_16 devpayments13_16 Xpayments1_16_2 Xdev13_16_2 interv_1 if intervention != "No Prime"
  local b = _b[Xdev13_16_2]
  test Xdev13_16_2
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local testtext "Coefficient on overall average greater with informational than hedonic prime"
  local b = _b[Xpayments1_16_2]
  test Xpayments1_16_2
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  *Binned deviation tests.
  local testtext "Coefficient on binned round 13-16 deviations greater with hedonic than informational prime"
  `model' keepallocator payments1_16 devcuts Xpayments1_16_2 Xdevcuts_2 interv_1 if intervention != "No Prime"
  local b = _b[Xdevcuts_2]
  test Xdevcuts
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Binned,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local testtext "Coefficient on overall average greater with informational than hedonic prime"
  local b = _b[Xpayments1_16_2]
  test Xpayments1_16_2
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Binned,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n

  capture drop *5_8
  
*Interactive model.
`model' keepallocator Xpayavg1_16_* interv_*

*Test equality of coefficients for each intervention.
di "Test of hedonic cutpoint coefficient versus informational."
test Xpayavg1_16_1=Xpayavg1_16_2
di "Test of hedonic cutpoint coefficient versus no prime."
test Xpayavg1_16_1=Xpayavg1_16_3
di "Test of informational cutpoint coefficient versus no prime."
test Xpayavg1_16_2=Xpayavg1_16_3


****************************
*More flexible lag tests.
****************************
*Koyck lag models.
local repl "replace"
local tablea4 "../papertables/TableA03_DecayModelsByPrime.out"
*foreach type in "continuous" "cutpoint" {
foreach type in "cutpoint" {
  preserve
  di "`type'" _n
  gen decay = _n/100 in 1/100
  gen float rsquared_none = .
  gen float rsquared_hedon = .
  gen float rsquared_info = .
  *Loop over values of decay, calculated koyck model given decay, and store rsquared.
  gen koycked = 0
  label variable koycked "Decay weighted payments in 1-16"
  if ("`type'" == "cutpoint") {
    label variable koycked "Decay weighted payment > 1200 in 1-16"
  }
  forvalues i = 1/100 {
    qui replace koycked = 0
    forvalues rd = 1/16 {
      local dec = decay in `i'
      *di "Decay value `dec', round `rd'."
      if ("`type'" == "cutpoint") {
        qui replace koycked = koycked + (`dec'^(16-`rd'))*(pay`rd' > 1200)
      }
      else {
        qui replace koycked = koycked + (`dec'^(16-`rd'))*pay`rd'/`denom'
      }     
    }

    qui `model' keepallocator koycked if intervention == "No Prime"
    *Validating statistic depends on model type.
    if ("`model'" == "reg") {
      local rsqstat `e(r2)'
    }
    else if ("`model'" == "probit") {
      local rsqstat `e(r2_p)'
    }
    else {
      di "model not known."
    }
    qui replace rsquared_none = `rsqstat' in `i'

    qui `model' keepallocator koycked if intervention == "Hedonic Prime"
    *Validating statistic depends on model type.
    if ("`model'" == "reg") {
      local rsqstat `e(r2)'
    }
    else if ("`model'" == "probit") {
      local rsqstat `e(r2_p)'
    }
    else {
      di "model not known."
    }
    qui replace rsquared_hedon = `rsqstat' in `i'

    qui `model' keepallocator koycked if intervention == "Informational Prime"
    *Validating statistic depends on model type.
    if ("`model'" == "reg") {
      local rsqstat `e(r2)'
    }
    else if ("`model'" == "probit") {
      local rsqstat `e(r2_p)'
    }
    else {
      di "model not known."
    }
    qui replace rsquared_info = `rsqstat' in `i' 
  }

  *Write out maximum Koyck models for each intervention, along with the p-value for a model
  *with only round 16 payments.
  qui gen rd16pay = pay16
  if ("`type'" == "cutpoint") {
    qui replace rd16pay = (pay16 > 1200)
  }
  
  gsort - rsquared_none
  qui replace koycked = 0
  forvalues rd = 1/16 {
    local dec = decay in 1
    if ("`type'" == "cutpoint") {
      qui replace koycked = koycked + (`dec'^(16-`rd'))*(pay`rd' > 1200)
    }
    else {
      qui replace koycked = koycked + (`dec'^(16-`rd'))*pay`rd'/`denom'
    }     
  }

  qui `model' keepallocator koycked if intervention == "No Prime"
  outreg using "`tablea4'", se ctitle("Allocator Retention, Koyck Decay, No Prime") addstat("R-Squared maximizing decay (on [0,1])",`dec') adec(6) bracket rdec(3) 3aster `repl'
  local repl "append"

  gsort - rsquared_info
  qui replace koycked = 0
  forvalues rd = 1/16 {
    local dec = decay in 1
    if ("`type'" == "cutpoint") {
      qui replace koycked = koycked + (`dec'^(16-`rd'))*(pay`rd' > 1200)
    }
    else {
      qui replace koycked = koycked + (`dec'^(16-`rd'))*pay`rd'/`denom'
    }     
  }

  qui `model' keepallocator koycked if intervention == "Informational Prime"
  outreg using "`tablea4'", se ctitle("Allocator Retention, Koyck Decay, Informational Prime") addstat("R-Squared maximizing decay (on [0,1])",`dec') adec(6) bracket rdec(3) 3aster append

  gsort - rsquared_hedon
  qui replace koycked = 0
  forvalues rd = 1/16 {
    local dec = decay in 1
    if ("`type'" == "cutpoint") {
      qui replace koycked = koycked + (`dec'^(16-`rd'))*(pay`rd' > 1200)
    }
    else {
      qui replace koycked = koycked + (`dec'^(16-`rd'))*pay`rd'/`denom'
    }     
  }

  qui `model' keepallocator koycked if intervention == "Hedonic Prime"
  outreg using "`tablea4'", se ctitle("Allocator Retention, Koyck Decay, Hedonic Prime") addstat("R-Squared maximizing decay (on [0,1])",`dec') adec(6) bracket rdec(3) 3aster append

  *Plot of r-squared by Koyck coefficient.
  foreach var of varlist rsquared_* {
    *Normalize to 1.
    qui summ `var'
    qui replace `var' = `var'/`r(max)'
  }
  gsort - decay
  twoway (scatter rsquared_hedon decay, msymbol(circle) mcolor(black)) (scatter rsquared_info decay, msymbol(square) mcolor(lime)) (scatter rsquared_none decay, msymbol(triangle) mcolor(bluishgray)), ytitle("Model R-Squared, Normalized to Maximum") xtitle(Decay coefficient) title("R-Squared of Retention Model, By Prime and Decay Coefficient", size(medium))  legend(order(1 "Hedonic prime" 2 "Information prime" 3 "No prime") title(Intervention)) scheme(s1mono)
  *graph export "../graphs/RSquaredByDecay-VaryingPrime-`type'.eps", replace
  restore
}

****************************
*Check on randomization.
****************************
foreach var of varlist interv_* {
  `model' `var' pay1-pay16
  testparm pay*
}

capture log close
